<section class="additional-info">
    <h3>{{ _('Additional Info') }}</h3>
    <table class="table table-striped table-bordered table-condensed">
      <thead>
        <tr>
          <th scope="col">{{ _('Field') }}</th>
          <th scope="col">{{ _('Value') }}</th>
        </tr>
      </thead>
      <tbody>
        {% block package_additional_info %}
        <tr>
            <td colspan="2">
                Conteúdo informações adicionais
            </td>
        </tr>
        {% endblock %}
      </tbody>
    </table>
  </section>
