.nav-color{
    background-color: #EEEEEE;
}

.nav-margin{
    margin-left: -60px;
    margin-right: -60px;
}

#collapseForm{
    background-color: #EEEEEE;
    margin-left: -36px;
    margin-right: -36px;
}

label::after{
    content: "" !important;
}

.pontilhado-meta{
    border-style: dashed;
    border-color: #0A5190;
    background-color: rgb(183, 234, 238);
    padding: 16px;
    padding-left: 60px;
    padding-right: 60px;
    color: #0A5190;
}

.pontilhado-recursos{
    border-style: dashed;
    border-color: #0A5190;
    background-color: rgb(183, 234, 238);
    color: #0A5190;
}

.add-meta{
    padding: 10px;
}

input::placeholder{
    color:#9ea2b0;
}

#btn-coluna{
    padding: 0%!important;
}

.input-style{
    width: 10rem!important;
    padding-top: 4%!important;
    border-color: #6d7278!important;
    background-color: #6d7278!important;
    color: white!important;
}

.margin-preview{
    margin-left:-17px!important;
    margin-right: -17px!important;
    margin-top: -17px!important;
}
