{#
Renders a list of resources with icons and view links.

resources - A list of resources (dicts) to render
pkg - A package dict that the resources belong to.

Example:

    {% snippet "package/snippets/resources_list.html", pkg=pkg, resources=pkg.resources %}

#}
<section id="dataset-resources" class="resources">
    <h2>{{ _('Data and Resources') }}</h2>
    {% block resource_list %}
    <h2>conteudo</h2>
    {% endblock %}
</section>
